@@ -1,5 +1,3 @@
-"""minos.api_gateway.rest.service module."""
-
 import logging
 
 from aiohttp import (
@@ -12,30 +10,30 @@ from aiomisc.service.aiohttp import (
     AIOHTTPService,
 )
 
-from minos.api_gateway.common import (
-    MinosConfig,
+from .config import (
+    ApiGatewayConfig,
 )
-from minos.api_gateway.rest import (
-    handler,
+from .handler import (
+    orchestrate,
 )
 
 logger = logging.getLogger(__name__)
 
 
 class ApiGatewayRestService(AIOHTTPService):
-    def __init__(self, address: str, port: int, config: MinosConfig):
+    def __init__(self, address: str, port: int, config: ApiGatewayConfig):
         self.config = config
         super().__init__(address, port)
 
     async def create_application(self) -> web.Application:
         middlewares = list()
-        if self.config.cors.enabled:
+        if self.config.rest.cors.enabled:
             middlewares = [cors_middleware(allow_all=True)]
 
         app = web.Application(middlewares=middlewares)
 
         app["config"] = self.config
 
-        app.router.add_route("*", "/{endpoint:.*}", handler.orchestrate)
+        app.router.add_route("*", "/{endpoint:.*}", orchestrate)
 
         return app
